@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::0_90::Role::API;
-$Search::Elasticsearch::Client::0_90::Role::API::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::0_90::Role::API::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Client::0_90::Role::API::VERSION = '6.81';
+use Moo::Role;
 with 'Search::Elasticsearch::Role::API';
 
 use Search::Elasticsearch::Util qw(throw);
@@ -1186,7 +1185,7 @@ Search::Elasticsearch::Client::0_90::Role::API - This class contains the spec fo
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 DESCRIPTION
 
