@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::0_90::Role::Bulk;
-$Search::Elasticsearch::Client::0_90::Role::Bulk::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::0_90::Role::Bulk::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Client::0_90::Role::Bulk::VERSION = '6.81';
+use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -287,7 +286,7 @@ Search::Elasticsearch::Client::0_90::Role::Bulk - Provides common functionality
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 AUTHOR
 
