@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::0_90::Role::Scroll;
-$Search::Elasticsearch::Client::0_90::Role::Scroll::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::0_90::Role::Scroll::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Client::0_90::Role::Scroll::VERSION = '6.81';
+use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Devel::GlobalDestruction;
@@ -65,7 +64,7 @@ Search::Elasticsearch::Client::0_90::Role::Scroll - Provides common functionalit
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 AUTHOR
 
