@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::0_90::TestServer;
-$Search::Elasticsearch::Client::0_90::TestServer::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::0_90::TestServer::VERSION = '6.801';use strict;
+$Search::Elasticsearch::Client::0_90::TestServer::VERSION = '6.81';
+use strict;
 use warnings;
 
 #===================================
@@ -43,7 +42,7 @@ Search::Elasticsearch::Client::0_90::TestServer - Client-specific backend for Se
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 AUTHOR
 
